import 'dart:async';

import 'package:call_log/call_log.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_background_service/flutter_background_service.dart';
import 'package:flutter_sms/flutter_sms.dart';
import 'package:project_telephony/ui/home/content_page.dart';
import 'package:project_telephony/utils/headers.dart';
import 'package:telephony/telephony.dart';

class HomePage extends StatefulWidget {
  const HomePage({Key? key}) : super(key: key);

  @override
  _HomePageState createState() => _HomePageState();
}
void _sendSMS(String message, List<String> recipients) async {
  try{
    String result =
    await sendSMS(message: message, recipients: recipients, sendDirect: true);
    print(result);
  } on PlatformException catch(e){
    print(e.toString());
  }
}
Future<void> initializeService() async {
  final service = FlutterBackgroundService();
  service.setNotificationInfo(title: '短信助手', content: '正在后台运行');
  await service.configure(
    androidConfiguration: AndroidConfiguration(
      onStart: onStart,
      autoStart: true,
      isForegroundMode: true,
    ),
    iosConfiguration: IosConfiguration(
      autoStart: true,
      onForeground: onStart,
      onBackground: onIosBackground,
    ),
  );
}

void onIosBackground() {
  WidgetsFlutterBinding.ensureInitialized();
  // print('FLUTTER BACKGROUND FETCH');
}

void onStart() {
  int flag = 0;
  String phoneNum;
  String   callState;
  WidgetsFlutterBinding.ensureInitialized();
  Timer.periodic(const Duration(seconds: 1), (timer) async {
    CallState state = await Telephony.instance.callState;
    callState = state.name;
    // print(callState!+" $flag");
    if (callState == "IDLE") {
      if (flag != 0) {
        flag = 0;
        // print("object");
        final Iterable<CallLogEntry> result = await CallLog.query();
        // print(phoneNum);
        // String message = "This is a test message!";
        // List<String> recipents = ["10000", "10086"];
        // String _result = await sendSMS(message: message, recipients: recipents, sendDirect: true)
        //     .catchError((onError) {
        //   print(onError);
        // });
        // print(_result);
        phoneNum = result.first.number!;
        // List<String> recipents=[
        //   phoneNum
        // ];
        if(phoneNum.isEmpty){
          print("At Least 1 Person or Message Required");
        }else{
          print("你好"+phoneNum);
          _sendSMS("你好", [phoneNum]);
          print("你好"+phoneNum);
        }
        // final SmsSendStatusListener listener = (SendStatus status) {
        //   print(status);
        // };
        // Phone.telephony.sendSms(
        //   to: phoneNum!,
        //   message: "hello",
        //   statusListener: listener,
        //   isMultipart: true,
        //
        // );
      }
    } else if (callState == "RINGING") {
      flag++;
    } else if (callState == "OFFHOOK") {
      flag++;
    }
  });
}

class Phone {
  static Telephony telephony = Telephony.instance;
}

class _HomePageState extends State<HomePage> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    Future.delayed(const Duration(milliseconds: 0), () async {
      //Hive.initFlutter;
     await  initializeService();

    });
  }
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        extendBodyBehindAppBar: true,
        extendBody: true,
        body: SafeArea(
          child: Column(
            children: [
              Container(
                  child: Image.asset(
                Assets.images.homeBg.path,
                height: 722.w,
                width: 722.w,
              )),
              _getBody(),
            ],
          ),
        ));
  }

  _getBody() {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: 64.w),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            "短信帮手",
            style: TextStyle(
                fontSize: 64.sp,
                color: const Color(0xFF333333),
                fontWeight: FontWeight.bold),
          ),
          32.hb,
          Text(
            "希望能成为您的短信小助手",
            style: TextStyle(fontSize: 32.sp, color: const Color(0xFF999999)),
          ),
          50.hb,
          _getContainer("接听后", "编辑接听后发送的短信内容", Assets.images.answer.path,
              const Color(0xFF74BCFF), const Color(0xFF1890FF)),
          30.hb,
          _getContainer("拒接/未接后", "编辑拒接/未接后发送的短信内容", Assets.images.refused.path,
              const Color(0xFF72E4C8), const Color(0xFF13CA9D))
        ],
      ),
    );
  }

  _getContainer(String title, String text, String image, Color cl1, Color cl2) {
    return GestureDetector(
        onTap: () {
          print(title);
          if (title == "接听后") {
            Get.to(() => const ContentPage(
                  isAnswer: true,
                ));
          } else {
            Get.to(() => const ContentPage(
                  isAnswer: false,
                ));
            print("未接听");
          }
        },
        child: Stack(
          children: [
            Align(
              child: Container(
                decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(16.w),
                    gradient: LinearGradient(
                        begin: Alignment.centerLeft,
                        end: Alignment.centerRight,
                        colors: [cl1, cl2])),
                width: 622.w,
                height: 192.w,
              ),
            ),
            Positioned(
              child: Row(
                children: [
                  Container(
                    padding: EdgeInsets.only(
                      left: 48.w,
                      top: 35.w,
                    ),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text(title,
                            style: TextStyle(
                                fontSize: 36.sp,
                                color: const Color(0xFFFFFFFF),
                                fontWeight: FontWeight.bold)),
                        24.hb,
                        Text(
                          text,
                          style: TextStyle(
                              fontSize: 27.sp,
                              color: const Color(0xFFFFFFFF).withOpacity(0.6)),
                        ),
                      ],
                    ),
                  ),
                  // Padding(
                  //   padding: EdgeInsets.only(top: 40.w),
                  //   child:

                  // )
                ],
              ),
            ),
            Positioned(
              bottom: 0,
              right: 0,
              child: Image.asset(
                image,
                width: 166.w,
                height: 152.w,
                fit: BoxFit.fill,
              ),
            )
          ],
        )
        //     Container(
        //   decoration: BoxDecoration(
        //       borderRadius: BorderRadius.circular(16.w),
        //       gradient: LinearGradient(
        //           end: Alignment.centerLeft,
        //           begin: Alignment.centerRight,
        //           colors: [cl1, cl2])),
        //   child:

        // ),
        );
  }
}
